@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.015_03';
+our $VERSION = '0.016_01';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -127,11 +127,8 @@ __PACKAGE__->add_property( 'alien_msys' => 0 );
 # Alien packages that provide build dependencies
 __PACKAGE__->add_property( 'alien_bin_requires' => {} );
 
-# Alien packages that can/should be installed directory into the blib directory by the `./Build' command
-# rather than to the final location during the `./Build install` step.
-# This is the default when building an ACTIVESTATE_PPM_BUILD because AS does not do `./Build install` at
-# all when building a PPM
-__PACKAGE__->add_property( 'alien_stage_install' => $ENV{ACTIVESTATE_PPM_BUILD} ? 1 : 0 );
+# Do a staged install to blib instead of trying to install to the final location.
+__PACKAGE__->add_property( 'alien_stage_install' => 1 );
 
 ################
 #  ConfigData  #
@@ -265,7 +262,7 @@ sub ACTION_code {
     $self->SUPER::ACTION_code;
 
     # copy the compiled files into blib if running under blib scheme
-    $self->depends_on('alien_install') if $self->notes('alien_blib_scheme');
+    $self->depends_on('alien_install') if $self->notes('alien_blib_scheme') || $self->alien_stage_install;
   }
   
   my $module = $self->module_name;
@@ -289,8 +286,6 @@ sub Inline { shift; $module->Inline(\@_) }
 EOF
     close $fh;
   }
-
-  $self->depends_on('alien_install') if $self->alien_stage_install;
 }
 
 sub ACTION_alien_code {
@@ -584,6 +579,7 @@ sub alien_library_destination {
 sub alien_detect_blib_scheme {
   my $self = shift;
 
+  return 0 if $self->alien_stage_install;
   return $ENV{ALIEN_BLIB} if defined $ENV{ALIEN_BLIB};
 
   # check to see if Alien::Base::ModuleBuild is running from blib.
